import React,{Component} from 'react';
import {Button, message, Popconfirm} from "antd";
import DataTable from "@/components/common/DataTable";
import {getCategoryState} from '@/utils/tools';
import {getSuperList,deleteState,locationChange} from './services/API';
import {ProFormSelect} from "@ant-design/pro-form";
import CategoryOperation from './components/categoryOperation';

class Business extends Component{
  constructor(props) {
    super(props);
    this.state={
      columns: [
        {
          title: '品类序号',
          dataIndex: 'sort',
          key: 'sort',
        },{
          title: '品类编号',
          dataIndex: 'cid',
          key: 'cid',
        }, {
          title: '品类名称',
          dataIndex: 'cname',
          key: 'cname',
          searchBool: true,
        },  {
          title: '品类层级',
          dataIndex: 'layer',
          key: 'layer',
          searchBool: true,
          valueType: 'select',
          valueEnum: {
            '1': {
              text: '一级',
            },
            '2': {
              text: '二级',
            },
            '3': {
              text: '三级',
            },
          },
        }, {
          title: '上级品类',
          dataIndex: 'superName',
          key: 'superId',
          searchBool: true,
          renderFormItem: () => {
            return (
              <ProFormSelect label='' request={this.getSuperList}/>
            );
          },
        },{
          title: '品类状态',
          dataIndex: 'status',
          key: 'status',
          searchBool: true,
          renderFormItem: () => {
            return (
              <ProFormSelect label='' request={this.getCategoryStateList}/>
            );
          },
          render: text => { return getCategoryState(text) }
        },{
          title: '品类状态',
          dataIndex: 'id',
          key: 'id',
          fixed: 'right',
          width: 220,
          align:'center',
          render: (text,record,_,action)=>{
            return (
              <>
                <Popconfirm
                  title="是否删除?"
                  onConfirm={(e)=>{e.stopPropagation();this.deleteState(text,action)}}
                  onCancel={(e)=>{e.stopPropagation();}}
                  okText="确认"
                  cancelText="取消"
                  placement="topLeft">
                  <Button size='small' type="link" onClick={(e)=>e.stopPropagation()}>删除</Button>
                </Popconfirm>
                <Button size='small' type="link" onClick={(e)=>{e.stopPropagation();this.locationChange('1',record,action)}}>品类上移</Button>
                <Button size='small' type="link" onClick={(e)=>{e.stopPropagation();this.locationChange('0',record,action)}}>品类下移</Button>
              </>
            )
          }
        }
      ],
      typeVisible: false,
    }
  }

  async componentDidMount() {

  }

  locationChange = async (type,value,action) =>{
    message.loading({content:type === '1' ? '上移中...' : '上移中...',key:'locationChange'});
    const msg = await locationChange(value.id,value.sort,type);
    if(msg.error.length === 0){
      message.success({content:type === '1' ? '上移成功' : '下移成功',key:'locationChange',duration:2.5});
      action.reload();
    }else{
      message.error({content: msg.error[0].message ,key:'locationChange',duration:2.5});
    }
  }

  deleteState= async (id,action)=>{
    message.loading({content:'删除中...',key:'deleteState'});
    const msg = await deleteState(id);
    if(msg.error.length === 0){
      message.success({content:'删除成功',key:'deleteState',duration:2.5});
      action.reload();
    }else{
      message.error({content:msg.error[0].message,key:'deleteState',duration:2.5})
    }
  }

  getSuperList= async ()=>{
    const msg = await getSuperList(1);
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.cname,
          value: item.id
        });
      });
    }else{
      message.error(msg.error.message);
    }
    return theArr;
  }

  getCategoryStateList=async ()=>{
    return [
      {
        label: '正常',
        value: '0',
      },
      {
        label: '停用',
        value: '1',
      }
    ];
  }

  render() {
    const ref = React.createRef();
    return (
      <>
        <DataTable
          ref={ref}
          headerTitle='业务分类管理'
          url='/api/admin/Varieties/vtList'
          method='post'
          rowKey='id'
          scroll={{x:1100}}
          columns={this.state.columns}
          search={{
            filterType: 'query',
            labelWidth: 'auto',
            defaultCollapsed: false,
          }}
          onRow={(record) => ({
            onClick: (e) => {
              e.stopPropagation();
              this.setState({
                typeVisible: true,
                typeInfor: record
              })
            }
          })}
          toolBarRender={[
            <Button
              type='primary'
              key='addUser'
              onClick={(e)=>{
                e.stopPropagation();
                this.setState({
                  typeVisible: true,
                  typeInfor: ''
                })
              }}
            >
              新增品类
            </Button>
          ]}
        />
        {this.state.typeVisible && <CategoryOperation
          formRef={ref}
          visible={this.state.typeVisible}
          typeInfor={this.state.typeInfor}
          onCancel={()=>{
            this.setState({
              typeVisible: false,
              typeInfor: ''
            })
          }}
        />}
      </>
    );
  }
}

export default Business;
