import React,{Component} from 'react';
import {message} from "antd";
import {addProjectSize,orgProjectSize,getOrgProject} from '../services/API';
import ProForm, {ModalForm, ProFormDigit, ProFormSelect, ProFormText} from "@ant-design/pro-form";

class AddBusinessNorms extends Component{
  constructor(props) {
    super(props);
  }

  addProjectSize= async (value)=>{
    if(value.offset>10 || value.offset<0){
      message.warning('最低折扣请输入0到10之间的数字');
      return false;
    }
    message.loading({content:'保存中...',key:'addProjectSize'});
    value.pid = this.props.projectInfor.id;
    const msg = await addProjectSize(value);
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'addProjectSize',duration:2.5});
      this.props.formRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'addProjectSize',duration:2.5})
    }
  }

  componentDidMount() {
    if(this.props.businessNormsInfor){
      this.getOrgProject();
      this.ref.current.setFieldsValue({
        pname:this.props.businessNormsInfor.pname,
        price:this.props.businessNormsInfor.price,
        activityPrice:this.props.businessNormsInfor.activityPrice,
        offset:this.props.businessNormsInfor.offset,
        memberPrice:this.props.businessNormsInfor.memberPrice,
        activityFlag:this.props.businessNormsInfor.activityFlag,
        status:this.props.businessNormsInfor.status,
      })
    }
  }

  getOrgProject= async ()=>{
    const msg = await getOrgProject(this.props.projectInfor.id);
    if(msg.error.length === 0){
      this.ref.current.setFieldsValue({
        createName: msg.data.createName
      })
    }else{
      message.error(msg.error[0].message)
    }
  }

  orgProjectSize = async (value)=>{
    if(value.offset>10 || value.offset<0){
      message.warning('最低折扣请输入0到10之间的数字');
      return false;
    }
    delete value.createName;
    message.loading({content:'修改中...',key:'addProjectSize'});
    value.id = this.props.businessNormsInfor.id;
    const msg = await orgProjectSize(value);
    if(msg.error.length === 0){
      message.success({content:'修改成功',key:'addProjectSize',duration:2.5});
      this.props.formRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'addProjectSize',duration:2.5})
    }
  }

  ref = React.createRef();

  render() {
    return (
      <ModalForm
        formRef={this.ref}
        visible={this.props.visible}
        preserve={false}
        title={(this.props.businessNormsInfor ? '编辑项目规格(' : '新增项目规格(')+this.props.projectInfor.bname+')'}
        layout={this.props.isReadOnly?'horizontal':'vertical'}
        modalProps={{
          width: 520,
          maskClosable: true,
          onCancel: (e) => {e.stopPropagation();this.props.onCancel();},
        }}
        onFinish={this.props.isReadOnly? ()=>{this.props.onCancel();} :this.props.businessNormsInfor ? this.orgProjectSize:this.addProjectSize}
      >
        <ProForm.Group>
          <ProFormText
            readonly={this.props.isReadOnly}
            width='xs'
            rules={[
              {
                required:true,
                message:'请输入规格名称'
              }
            ]}
            placeholder="请输入规格名称"
            name="pname"
            label="规格名称"
          />
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="price"
            width='xs'
            label="市场价"
            placeholder="请输入市场价"
          />
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="activityPrice"
            width='xs'
            label="活动价"
            placeholder="请输入活动价"
          />
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="offset"
            width='xs'
            label="最低折扣"
            placeholder="请输入最低折扣"
          />
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="memberPrice"
            width='xs'
            label="会员价"
            placeholder="请输入会员价"
          />
          <ProFormSelect
            readonly={this.props.isReadOnly}
            width='xs'
            name="activityFlag"
            label="活动生效"
            placeholder="请选择活动生效"
            options={[
              {
                value: '0',
                label: '有效',
              },
              {
                value: '1',
                label: '无效',
              },
            ]}
          />
          {this.props.businessNormsInfor && <>
            <ProFormSelect
              readonly={this.props.isReadOnly}
              width='xs'
              name="status"
              label="项目状态"
              placeholder="请选择项目状态"
              options={[
                {
                  value: 0,
                  label: '正常',
                },
                {
                  value: 1,
                  label: '解散',
                },
              ]}
            />
            <ProFormText
              width='xs'
              name="createName"
              label="创建人"
              readonly
            />
          </>}
        </ProForm.Group>
      </ModalForm>
    );
  }
}

export default AddBusinessNorms;
