import React,{Component} from 'react';
import {Button, message, Cascader, Form} from 'antd';
import ProForm, {ModalForm, ProFormSelect, ProFormText} from "@ant-design/pro-form";
import { PlusOutlined } from '@ant-design/icons';
import {getAllCname,addProject} from '../services/API';
import {getAddressSelect} from "@/utils/tools";

class AddProject extends Component{
  constructor(props) {
    super(props);
    this.state={
      addressList: []
    }
  }

  getAllCname=async ()=>{
    const msg = await getAllCname();
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item,key) => {
        theArr.push({
          label: item.cname,
          value: key,
        });
      });
    }else{
      message.error(msg.error[0].message)
    }
    return theArr;
  }

  addUser=async (value)=>{
    message.loading({content:'保存中...',key:'addProject'});
    value.province = value.address[0] || ''; // 省
    value.city = value.address[1] || '';     // 市
    value.district = value.address[2] || ''; // 区
    value.country = value.address[0] === 0 ? 1 : 0;
    value.boutique = '0';                   // 是否精品(默认传0就行)
    const msg = await addProject(value);
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'addProject',duration:2.5});
      this.props.formRef.current.reload();
      return true;
    }else{
      message.error({content:msg.error[0].message,key:'addProject',duration:2.5})
    }
  }

  componentDidMount() {
    getAddressSelect().then(v=>{
      v.unshift({
        label: '全国',
        value: 0,
      });
      this.setState({
        addressList :v
      })
    })
  }

  render() {
    return (
      <ModalForm
        preserve={false}
        title='新增业务项目'
        trigger={
          <Button type="primary">
            <PlusOutlined />
            新建业务
          </Button>
        }
        modalProps={{
          width: 380
        }}
        onFinish={this.addUser}
      >
        <ProForm.Group>
          <ProFormText
            width="m"
            rules={[
              {
                required:true,
                message:'请输入业务项目名称'
              }
            ]}
            placeholder="请输入业务项目名称"
            name="bname"
            label="业务项目名称"
          />
        </ProForm.Group>
        <ProForm.Group>
          <ProFormSelect
            width="m"
            rules={[
              {
                required:true,
                message:'请选择业务品类'
              }
            ]}
            placeholder="请选择业务品类"
            label='业务品类'
            name="cid"
            request={this.getAllCname}/>
        </ProForm.Group>
        <Form.Item
          label="省-市-区:"
          name='address'
          rules={[
            {
              required:true,
              message:'请选择省-市-区'
            }
          ]}
        >
          <Cascader
            changeOnSelect
            style={{
              width: '329px',
            }}
            options={this.state.addressList}
            placeholder='请选择省-市-区'/>
        </Form.Item>
      </ModalForm>
    )
  }
}

export default AddProject;
