import React,{Component} from 'react';
import ProForm, {
  ProFormText,
  ProFormSelect,
  ProFormDigit,
  ProFormTextArea,
} from '@ant-design/pro-form';
import {Cascader, Form, message} from "antd";
import {getAllCname,getOrgProject,updateProject} from '../services/API';
import {getAddressSelect, getprovince} from "@/utils/tools";

class BasicInformation extends Component{
  constructor(props) {
    super(props);
    this.state={
      loading: false,
      activityFlag: '',
      createTimeFormattedDate: '',
      createName: '',
      address: [],
      addressList: [],
    }
  }

  getAllCname=async ()=>{
    const msg = await getAllCname();
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.cname,
          value: item.id,
        });
      });
    }else{
      message.error(msg.error[0].message)
    }
    return theArr;
  }

  getOrgProject= async ()=>{
    this.setState({
      loading: true,
    })
    const msg = await getOrgProject(this.props.projectInfor.id);
    if(msg.error.length === 0){
      let arr = [];
      msg.data.province && arr.push(msg.data.country === "1"?0:parseInt(msg.data.province));
      msg.data.city && arr.push(parseInt(msg.data.city));
      msg.data.district && arr.push(parseInt(msg.data.district));
      msg.data.country === "1" ? arr[0]=0 : null;
      this.setState({
        createName: msg.data.createName,
        createTimeFormattedDate: msg.data.createTimeFormattedDate,
        address: arr,
      })
      let addres = [];
      if(!isNaN(parseInt(msg.data.province))){
        addres.push(getprovince(parseInt(msg.data.province)));
      }
      if(!isNaN(parseInt(msg.data.city))){
        addres.push(getprovince(parseInt(msg.data.city)));
      }
      if(!isNaN(parseInt(msg.data.district))){
        addres.push(getprovince(parseInt(msg.data.district)));
      }
      this.formRef.current.setFieldsValue({
        bname:msg.data.bname,
        cid:msg.data.cid,
        address:arr[0] === 0 ? ['全国'] : addres,
        price:msg.data.price,
        offset:msg.data.offset,
        memberPrice:msg.data.memberPrice,
        firstPayment:msg.data.firstPayment,
        activityPrice:msg.data.activityPrice,
        status:msg.data.status,
        type:msg.data.type,
        projectUrl:msg.data.projectUrl,
        clientSize:msg.data.clientSize,
        valueEffect:msg.data.valueEffect,
        introduce:msg.data.introduce,
        activityFlag: msg.data.activityFlag,
      })
    }else{
      message.error(msg.error[0].message)
    }
    this.setState({
      loading: false,
    })
  }

  updateProject= async (value)=>{
    if(this.state.address){
      value.address = this.state.address;
    }
    value.province = value.address[0] || value.address[0] === 0 ?  value.address[0] : null; // 省
    value.city = value.address[1] || null;     // 市
    value.district = value.address[2] || null; // 区
    value.country = value.address[0] === 0 ? 1 : 0; // 是否全国
    delete value.address;
    value.id = this.props.projectInfor.id;
    message.loading({content:'保存中...',key:'updateProject'});
    const msg = await updateProject(value);
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'updateProject',duration:2.5});
      this.props.formRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'updateProject',duration:2.5})
    }
  }

  componentDidMount() {
    this.getOrgProject();
    getAddressSelect().then(v=>{
      v.unshift({
        label: '全国',
        value: 0,
      });
      this.setState({
        addressList :v
      })
    })
  }

  formRef=React.createRef();

  render() {
    return (
      <ProForm
        formRef={this.formRef}
        onFinish={this.updateProject}
        layout={this.props.isReadOnly?'horizontal':'vertical'}
        submitter={!this.props.isReadOnly}
      >
        <ProForm.Group>
          <ProFormText
            readonly={this.props.isReadOnly}
            name="bname"
            width='s'
            label="项目名称"
            placeholder="请输入项目名称"
            rules={[
              {
                required: true,
                message: '请输入项目名称！',
              },
            ]}
          />
          <ProFormSelect
            readonly={this.props.isReadOnly}
            name="cid"
            width='s'
            label='业务品类'
            placeholder="请选择业务品类"
            request={this.getAllCname}
            rules={[
              {
                required: true,
                message: '请选择业务品类',
              },
            ]}
          />
          <Form.Item
            label="省-市-区:"
            name='address'
            rules={[
              {
                required:true,
                message:'请选择省-市-区'
              }
            ]}
          >
            {this.props.isReadOnly ? this.formRef.current && this.formRef.current.getFieldsValue(['address']).address : <Cascader
              changeOnSelect
              style={{
                width: '216px',
              }}
              options={this.state.addressList}
              onChange={()=>{
                this.setState({
                  address: ''
                })
              }}
              placeholder='请选择省-市-区'/>}
          </Form.Item>
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="price"
            width='s'
            label="市场价"
            placeholder="请输入市场价"
            rules={[
              {
                required: true,
                message: '请输入市场价',
              },
            ]}
          />
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="firstPayment"
            label="首付金额"
            width='s'
            placeholder="请输入首付金额"
            rules={[
              {
                required: true,
                message: '请输入首付金额',
              },
            ]}
          />
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="activityPrice"
            width='s'
            label="活动价"
            placeholder="请输入活动价"
          />
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="offset"
            label="最低折扣"
            width='s'
            placeholder="请输入最低折扣"
          />
          <ProFormDigit
            readonly={this.props.isReadOnly}
            name="memberPrice"
            label="会员价"
            width='s'
            placeholder="请输入会员价"
          />
          <ProFormSelect
            readonly={this.props.isReadOnly}
            width="s"
            name="activityFlag"
            label="活动生效"
            placeholder="请选择活动生效"
            options={[
              {
                value: '0',
                label: '有效',
              },
              {
                value: '1',
                label: '无效',
              },
            ]}
          />
          <ProFormSelect
            readonly={this.props.isReadOnly}
            width="s"
            name="status"
            label="项目状态"
            placeholder="请选择项目状态"
            options={[
              {
                value: '0',
                label: '正常',
              },
              {
                value: '1',
                label: '解散',
              },
            ]}
          />
          <ProFormSelect
            readonly={this.props.isReadOnly}
            width="s"
            name="type"
            label="项目分类"
            placeholder="请选择项目分类"
            options={[
              {
                value: 0,
                label: '通用',
              },
              {
                value: 1,
                label: '专利',
              },
              {
                value: 2,
                label: '软著',
              },
              {
                value: 3,
                label: '审计',
              },
              {
                value: 4,
                label: '双软',
              },
              {
                value: 5,
                label: '高新',
              },
              {
                value: 6,
                label: '商标',
              }
            ]}
          />
        </ProForm.Group>
        <div style={{display:'flex',alientItem:'center',paddingBottom:'25px'}}>
          <div style={{paddingRight:'35px'}}>
            <span>创建人:</span>
            <span style={{paddingLeft:'15px'}}>{this.state.createName}</span>
          </div>
          <div style={{paddingRight:'35px'}}>
            <span>创建时间:</span>
            <span style={{paddingLeft:'15px'}}>{this.state.createTimeFormattedDate}</span>
          </div>
        </div>
        <ProForm.Group>
          <ProFormTextArea
            readonly={this.props.isReadOnly}
            name="projectUrl"
            width='m'
            label="项目地址"
            placeholder="请输入项目地址"
          />
        </ProForm.Group>
        <ProForm.Group>
          <ProFormTextArea
            readonly={this.props.isReadOnly}
            name="introduce"
            width='m'
            label="业务项目服务内容"
            placeholder="请输入业务项目服务内容"
          />
        </ProForm.Group>
        <ProForm.Group>
          <ProFormTextArea
            readonly={this.props.isReadOnly}
            name="valueEffect"
            width='m'
            label="业务项目价值及作用"
            placeholder="请输入业务项目价值及作用"
          />
        </ProForm.Group>
        <ProForm.Group>
          <ProFormTextArea
            readonly={this.props.isReadOnly}
            name="clientSize"
            width='m'
            label="业务项目客户基本条件"
            placeholder="请输入业务项目客户基本条件"
          />
        </ProForm.Group>
      </ProForm>
    )
  }
}

export default BasicInformation;
