import React,{Component} from 'react';
import AddBusinessNorms from "./addBusinessNorms";
import DataTable from "@/components/common/DataTable";
import {getGameState} from '@/utils/tools';
import { PlusOutlined } from '@ant-design/icons';
import {Button, message, Popconfirm} from "antd";
import {deleteProjectSize} from '../services/API';
import {ProFormText} from "@ant-design/pro-form";

class BusinessNorms extends Component{
  constructor(props) {
    super(props);
    this.state={
      columns:[
        {
          title: "业务项目名称",
          dataIndex: "bname",
          key: "bname",
        },
        {
          title: "规格名称",
          dataIndex: "pname",
          key: "pname",
        },
        {
          title: "市场价",
          dataIndex: "price",
          key: "price",
        },
        {
          title: "最低折扣",
          dataIndex: "offset",
          key: "offset",
        },
        {
          title: "会员价",
          dataIndex: "memberPrice",
          key: "memberPrice",
        },
        {
          title: "活动价",
          dataIndex: "activityPrice",
          key: "activityPrice",
        },
        {
          title: "活动生效标识",
          dataIndex: "activityFlag",
          key: "activityFlag",
          render: (text) => {
            return getGameState(text);
          },
        },
        {
          title: "状态",
          dataIndex: "status",
          key: "status",
          valueType: 'select',
          valueEnum: {
            '0': {
              text: '正常',
              status: 'Success'
            },
            '1': {
              text: '停用',
              status: 'Error'
            },
          },
        },{
          title: '操作',
          dataIndex: 'id',
          key: 'id',
          render: (text,record,key,action) => { return (
            <Popconfirm
              title="是否删除?"
              onConfirm={(e)=>{e.stopPropagation();this.deleteProjectSize(text,action)}}
              onCancel={(e)=>{e.stopPropagation();}}
              okText="确认"
              cancelText="取消"
              placement="topLeft">
              <Button disabled={this.props.isReadOnly} type='primary' danger onClick={(e)=>e.stopPropagation()}>删除</Button>
            </Popconfirm>
          ) }
        }
      ],
      visible: false,
      businessNormsInfor: '',
    }
  }

  deleteProjectSize= async (id,action)=>{
    message.loading({content:'删除中...',key:'deleteProjectSize'});
    const msg = await deleteProjectSize(id);
    if(msg.error.length === 0) {
      message.success({content: '删除成功', key: 'deleteProjectSize', duration: 2.5});
      action.reload();
    }else{
      message.error({content:msg.error[0].message,key:'deleteProjectSize',duration:2.5});
    }
  }

  render() {
    const ref = React.createRef();
    return (
      <>
        <DataTable
          ref={ref}
          url='/api/admin/ProjectSize/listProjectSize'
          params={{
            pid:this.props.projectInfor.id,
          }}
          rowKey='id'
          scroll={{x:700}}
          search={false}
          columns={this.state.columns}
          onRow={(record) => ({
            onClick: (e) => {
              e.stopPropagation();
              this.setState({
                visible: true,
                businessNormsInfor: record
              })
            }
          })}
          toolBarRender={!this.props.isReadOnly && [
            <Button type="primary" key='addProject' onClick={()=>{
              this.setState({
                visible: true,
                businessNormsInfor: ''
              })
            }}>
              <PlusOutlined />
              新增项目规格
            </Button>
          ]}
        />
        {this.state.visible && <AddBusinessNorms
          {...this.props}
          key='addProject'
          formRef={ref}
          visible={this.state.visible}
          businessNormsInfor={this.state.businessNormsInfor}
          onCancel={()=>{
            this.setState({
              visible:false,
              businessNormsInfor: ''
            })
          }}
        />}
      </>
    )
  }
}

export default BusinessNorms;
