import React,{Component} from 'react';
import {AutoComplete, Form, message, Spin, Select, Modal} from "antd";
import { LoadingOutlined,ExclamationCircleOutlined } from '@ant-design/icons';
import ProForm, {ModalForm, ProFormSelect, ProFormText, ProFormTextArea} from "@ant-design/pro-form";
import {getSelectSuperId} from "@/services/user";
import {addOrganization,getSelectAllById,getSelectName,updateOrganization} from '../../services/API';
import {conditionOrganization, addressList} from '@/utils/dataDic';

const antIcon = <LoadingOutlined style={{ fontSize: 24 }} spin />;
const confirm = Modal.confirm;

class AddOrganization extends Component{
  constructor(props) {
    super(props);
    this.state={
      loading: false,
      modules: [],
      financeList: [],
      depNo: '',
      createTime: '',
      createId: '',
      superId: '',
      departmentList: [],
    }
    this.addOrganization = this.addOrganization.bind(this);
    this.updateOrganization = this.updateOrganization.bind(this);
  }

  addOrganization= async (value)=>{
    message.loading({content:'保存中...',key:'addOrganization'})
    const msg = await addOrganization(value);
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'addOrganization',duration:2.5});
      this.props.formRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'addOrganization',duration:2.5})
    }
  }

  updateOrganization= async (value)=>{
    let statusLv = value.status === '1';
    let superIdLv = value.superId !== this.state.superId;
    let _this = this;
    if(statusLv || superIdLv){
      confirm({
        title:'修改提醒',
        icon: <ExclamationCircleOutlined />,
        content: statusLv && superIdLv ? '确定要修改该组织的上级组织并且解散该部门吗?' : statusLv ? '确定要解散该部门吗?' : '确定要修改该组织的上级组织吗?',
        onOk() {
          _this.setUpdateOrganization(value);
        }
      })
    }else{
      this.setUpdateOrganization(value);
    }
  }

  // 部门
  departmentList = async() => {
    const msg = await getSelectSuperId();
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
    }else{
      message.info(msg.error[0].message)
    }
    this.setState({
      departmentList : theArr
    })
    return theArr;
  }

  citySelect = async () => {
    let option = [];
    await addressList.map((item) => {
      if(item.id){
        option.push({
          value: item.id,
          label: item.name
        });
      }
    });
    return option;
  }

  setUpdateOrganization= async (value)=>{
    message.loading({content:'保存中...',key:'updateOrganization'});
    value.id = this.props.organizationInfor.id;
    let arr = this.state.departmentList.filter(v=>v.value === value.superId || v.label === value.superId) || [];
    value.superId = arr[0].value;
    const msg = await updateOrganization(value);
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'updateOrganization',duration:2.5});
      this.props.formRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'updateOrganization',duration:2.5})
    }
  }

  getType=async ()=>{
    return [
      {
        label:'公司',
        value: '0',
      },
      {
        label:'部门',
        value: '1',
      },
      {
        label:'团队',
        value: '2',
      }
    ]
  }

  async componentDidMount() {
    await this.getModules('');
    await this.getFinanceList('');
   if(this.props.organizationInfor){
    await this.getSelectAllById();
   }
  }

  getSelectAllById= async ()=>{
    this.setState({
      loading: true
    })
    const msg = await getSelectAllById(this.props.organizationInfor.id);
    if(msg && Object.keys(msg).length !== 0){
      this.formRef.current.setFieldsValue({
        name: msg.name,
        managerId: msg.managerId,
        type: msg.type,
        superId: msg.superId,
        remarks: msg.remarks || '该组织没有职能说明，请完善！',
        status: msg.status,
        province: msg.province,
        abbreviation: msg.abbreviation,
        financeId: msg.financeId,
      });
      this.setState({
        superId:msg.superId
      })
      this.setState({
        depNo: msg.depNo,
        createTime: msg.createTime,
        createId: msg.createId
      })
    }else{
      message.error(msg.error.message);
    }
    this.setState({
      loading: false
    })
  }



  getModules=async (value)=>{
    const msg = await getSelectName(value);
    if(msg.error.length === 0){
      let theArr = [];
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
      this.setState({
        modules: theArr
      })
    }else{
      message.error(msg.error[0].message)
    }
  }

  getFinanceList=async (value)=>{
    const msg = await getSelectName(value);
    if(msg.error.length === 0){
      let theArr = [];
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
      this.setState({
        financeList: theArr
      })
    }else{
      message.error(msg.error[0].message)
    }
  }


  formRef = React.createRef();

  render() {
    return (
      <ModalForm
        formRef={this.formRef}
        visible={this.props.visible}
        preserve={false}
        title={this.props.organizationInfor ? '编辑组织' : '新建组织'}
        modalProps={{
          onCancel: (e) => {e.stopPropagation();this.props.onCancel();this.setState({fileList:[]})},
        }}
        onFinish={this.props.organizationInfor ? this.updateOrganization : this.addOrganization}
      >
        <Spin spinning={this.state.loading} indicator={antIcon}>
          {this.props.organizationInfor &&
          <div style={{display:'flex',alientItem:'center',paddingBottom:'25px'}}>
            <div style={{paddingRight:'35px'}}>
              <span>组织编号:</span>
              <span style={{paddingLeft:'15px'}}>{this.state.depNo}</span>
            </div>
            <div style={{paddingRight:'35px'}}>
              <span>创建人:</span>
              <span style={{paddingLeft:'15px'}}>{this.state.createId}</span>
            </div>
            <div>
              <span>创建时间:</span>
              <span style={{paddingLeft:'15px'}}>{this.state.createTime}</span>
            </div>
          </div>
          }
          <ProForm.Group>
            <ProFormText
              width="m"
              rules={[
                {
                  required:true,
                  message:'请输入组织名称'
                }
              ]}
              placeholder="请输入组织名称"
              name="name"
              label="组织名称"/>
            <Form.Item
              name="managerId"
              label="负责人"
            >
              <Select
                showSearch
                allowClear
                style={{width:'328px'}}
                options={this.state.modules}
                onSearch={this.getModules}
                optionFilterProp="label"
                placeholder="请选择负责人"
              />
            </Form.Item>
          </ProForm.Group>
          <ProForm.Group>
            <ProFormSelect
              width="m"
              label='组织类型'
              name="type"
              placeholder="请选择组织类型"
              rules={[
                {
                  required:true,
                  message:'请选择组织类型'
                }
              ]}
              valueEnum={
                {
                  '0':'公司',
                  '1':'部门',
                  '2':'团队',
                }}/>
            <ProFormSelect
              width="m"
              label='上级组织'
              name="superId"
              placeholder="请选择上级组织"
              rules={[
                {
                  required:true,
                  message:'请选择上级组织'
                }
              ]}
              request={this.departmentList}/>
          </ProForm.Group>
          {this.props.organizationInfor &&
            <>
              <ProForm.Group>
                <ProFormSelect
                  width="m"
                  label='组织状态'
                  name="status"
                  placeholder="请选择组织状态"
                  rules={[
                    {
                      required:true,
                      message:'请选择组织状态'
                    }
                  ]}
                  request={async ()=>{
                    return conditionOrganization;
                  }}/>
                <ProFormSelect
                  width="m"
                  label='省份'
                  name="province"
                  placeholder="请选择省份"
                  request={this.citySelect}/>
              </ProForm.Group>
              <ProForm.Group>
                <ProFormText
                  width="m"
                  placeholder="请输入缩写"
                  name="abbreviation"
                  label="缩写"/>
                <Form.Item
                  name="financeId"
                  label="财务负责人"
                >
                  <Select
                    showSearch
                    allowClear
                    rules={[
                      {
                        required:true,
                        message:'请输入财务负责人'
                      }
                    ]}
                    style={{width:'328px'}}
                    options={this.state.financeList}
                    onSearch={this.getFinanceList}
                    optionFilterProp="label"
                    placeholder="请输入财务负责人"
                  />
                </Form.Item>
              </ProForm.Group>
            </>
          }
          <ProForm.Group>
            <ProFormTextArea
              width="m"
              placeholder="请输入组织职能说明"
              name="remarks"
              label="组织职能说明"/>
          </ProForm.Group>
        </Spin>
      </ModalForm>
    )
  }
}

export default AddOrganization;
