import React,{Component} from 'react';
import {Button, message, Popconfirm} from "antd";
import {getPattern,getCondition} from '@/utils/tools';
import DataTable from "@/components/common/DataTable";
import {ProFormSelect} from "@ant-design/pro-form";
import {getSelectSuperId} from "@/services/user";
import AddOrganization from './components/addOrganization';
import {deleteById} from './services/API';

// 部门
const departmentList = async() => {
  const msg = await getSelectSuperId();
  if(msg.error.length === 0){
    let theArr = [];
    msg.data.forEach((item) => {
      theArr.push({
        label: item.name,
        value: item.id
      });
    });
    return theArr;
  }else{
    message.info(msg.error[0].message)
  }
  return [];
}

class Mechanism extends Component{
  constructor(props) {
    super(props);
    this.state={
      columns: [
        {
          title: '组织编号',
          dataIndex: 'depNo',
          key: 'depNo',
          searchBool: true,
        }, {
          title: '组织名称',
          dataIndex: 'name',
          key: 'name',
          searchBool: true,
        }, {
          title: '负责人',
          dataIndex: 'managerName',
          key: 'managerName',
        },{
          title: '组织类型',
          dataIndex: 'type',
          key: 'type',
          searchBool: true,
          render: text => { return getPattern(text) },
          renderFormItem: () => {
            return (
              <ProFormSelect label='' request={this.getType}/>
            );
          },
        },  {
          title: '上级组织',
          dataIndex: 'superName',
          key: 'superId',
          searchBool: true,
          renderFormItem: () => {
            return (
              <ProFormSelect label='' request={departmentList}/>
            );
          },
        },{
          title: '组织状态',
          dataIndex: 'status',
          key: 'status',
          render: text => { return getCondition(text) }
        },{
          title: '操作',
          dataIndex: 'id',
          key: 'id',
          render: (text,record,key,action) => { return (
            <Popconfirm
              title="是否删除?"
              onConfirm={(e)=>{e.stopPropagation();this.deleteById(text,action)}}
              onCancel={(e)=>{e.stopPropagation();}}
              okText="确认"
              cancelText="取消"
              placement="topLeft">
                <Button type='primary' danger onClick={(e)=>e.stopPropagation()}>删除</Button>
            </Popconfirm>
          ) }
        }
      ],
      visible: false,
      organizationInfor: '',
    }
  }

  getType=async ()=>{
    return [
      {
        label:'公司',
        value: 0,
      },
      {
        label:'部门',
        value: 1,
      },
      {
        label:'团队',
        value: 2,
      }
    ]
  }

  deleteById=async (id,action)=>{
    message.loading({content:'删除中...',key:'deleteById'})
    const msg = await deleteById(id);
    if(msg.error.length === 0){
      message.success({content:'删除成功',key:'deleteById',duration:2.5});
      action.reload();
    }else{
      message.error({content:msg.error[0].message,key:'deleteById',duration:2.5});
    }
  }

  render() {
    const ref = React.createRef();
    return (
      <>
        <DataTable
          ref={ref}
          headerTitle='组织结构'
          url='/api/admin/organization/listOrganizationManagement'
          method='post'
          rowKey='id'
          scroll={{x:1000}}
          columns={this.state.columns}
          search={{
            filterType: 'query',
            labelWidth: 'auto',
            defaultCollapsed: false,
          }}
          onRow={(record) => ({
            onClick: (e) => {
              e.stopPropagation();
              this.setState({
                visible: true,
                organizationInfor: record,
              })
            }
          })}
          toolBarRender={[
            <Button
              type='primary'
              key='addUser'
              onClick={(e)=>{
                e.stopPropagation();
                this.setState({
                  visible: true,
                  organizationInfor: ''
                })
              }}
            >
              新增组织
            </Button>
          ]}
        />
        {this.state.visible && <AddOrganization
          formRef={ref}
          organizationInfor={this.state.organizationInfor}
          visible={this.state.visible}
          onCancel={()=>{
            this.setState({
              visible: false,
              organizationInfor: ''
            })
          }}
        /> }
      </>
    )
  }
}

export default Mechanism;
