import React,{Component} from 'react';
import {AutoComplete, Form, message, Spin} from "antd";
import ProForm, {ModalForm, ProFormSelect, ProFormText} from "@ant-design/pro-form";
import {post, station,cityArr} from "@/utils/dataDic";
import {splitUrl} from '@/utils/tools';
import {getSelectSuperId,getRolesList} from "@/services/user";
import {connectModel} from "@/services/common";
import ImgOperation from "@/components/common/ImgOperation";
import { LoadingOutlined } from '@ant-design/icons';
import {getSelectName,setInsertAdmin,getNewId,getSelectAllByid,getUserRole,updateAdmin} from '../services/API';

const { Option } = AutoComplete;
const antIcon = <LoadingOutlined style={{ fontSize: 24 }} spin />;

@connectModel('test', '@@initialState')
class AddUser extends Component{
  constructor(props) {
    super(props);
    this.state={
      loading: false,
      fileList: [],
      uploadImgLoading: false,
      modules: [],
      addId: '',
      details: {},
    }
    this.handleSearchModule= this.handleSearchModule.bind(this);
  }

  addUser= async (value) =>{
    if(this.state.uploadImgLoading){
      message.info('有图片正在上传中,请稍后');
      return false;
    }
    let superiorId ='';
    if(value.superiorId){
      let arr = this.state.modules.filter(v=>v.name === value.superiorId);
      if(arr.length){
        superiorId = arr[0].id
      }
    }
    message.loading({content:'保存中...',key:'addUser'})
    const msg = await setInsertAdmin({
      roles:value.roles,
      data:JSON.stringify({
        id:this.state.addId,
        email:value.email,
        position:value.position,
        mobile:value.mobile,
        status:'正常',
        contactMobile:value.contactMobile,
        name:value.name,
        duty:value.duty,
        headPortraitUrl:value.headPortraitUrl.fileList[0].response.data,
        departmentId:this.props.test.initialState.globalConfig.adminData.isSuperAdmin?value.departmentId:this.props.test.initialState.globalConfig.adminData.departmentId,
        superiorId:superiorId,
        district:value.district,
      })
    });
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'addUser',duration:2.5});
      this.props.tableRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'addUser',duration:2.5});
    }
  }

  updateAdmin= async (value)=>{
    if(this.state.uploadImgLoading){
      message.info('有图片正在上传中,请稍后');
      return false;
    }
    let superiorId ='';
    if(value.superiorId){
      let arr = this.state.modules.filter(v=>v.name === value.superiorId);
      if(arr.length){
        superiorId = arr[0].id
      }
    }
    message.loading({content:'保存中...',key:'addUser'})
    const msg = await updateAdmin({
      roles:value.roles,
      data:JSON.stringify({
        id:this.props.userId,
        email:value.email,
        position:value.position,
        mobile:value.mobile,
        status: value.status,
        contactMobile:value.contactMobile,
        name:value.name,
        duty:value.duty,
        headPortraitUrl:value.headPortraitUrl ? value.headPortraitUrl.fileList[0].response.data : '',
        departmentId:this.props.test.initialState.globalConfig.adminData.isSuperAdmin?value.departmentId:this.props.test.initialState.globalConfig.adminData.departmentId,
        superiorId:superiorId,
        district:value.district,
      })
    });
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'addUser',duration:2.5});
      this.props.tableRef.current.reload();
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'addUser',duration:2.5});
    }
  }

  getStation = async () => {
    station.map((v)=>{
      v.label = v.key;
      return v;
    })
    return station;
  }

  getPost = async () => {
    post.map((v)=>{
      v.label = v.key;
      return v;
    })
    return post;
  }

  getStatus = async  () =>{
    return [
      {
        label: '正常',
        value: '正常',
      },
      {
        label: '注销',
        value: '注销',
      },
      {
        label: '锁定',
        value: '锁定',
      }
    ]
  }

  getCityArr = async () => {
    cityArr.map((v)=>{
      v.label = v.key;
      return v;
    })
    return cityArr;
  }

  getRolesList=async (value)=>{
    const msg = await getRolesList(value);
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.roleName,
          value: item.id
        });
      });
    }else{
      message.error(msg.error[0].message)
    }
    return theArr;
  }

  departmentList = async() => {
    const msg = await getSelectSuperId();
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
    }else{
      message.info(msg.error[0].message)
    }
    return theArr;
  }

  handleSearchModule=async (value)=>{
    const msg = await getSelectName(value);
    if(msg.error.length === 0){
      this.setState({
        modules: msg.data
      })
    }else{
      message.error(msg.error[0].message)
    }
  }

  getNewId= async ()=>{
    const msg = await getNewId();
    if(msg.error.length === 0){
      this.setState({
        addId: msg.data
      })
    }else{
      message.error(msg.error[0].message)
    }
  }

  getUserRole= async (id)=>{
    const msg = await getUserRole(id);
    if(msg.error.length === 0){
      this.formRef.current.setFieldsValue({
        roles: msg.data,
      })
    }else{
      message.error(msg.error[0].message);
    }
  }

  getSelectAllByid= async (id)=>{
    const msg = await getSelectAllByid(id);
    if(msg.error.length === 0){
      this.setState({
        details: msg.data,
        fileList: msg.data.headPortraitUrl? splitUrl(msg.data.headPortraitUrl, ',', this.props.test.initialState.globalConfig.avatarHost + '/upload').fileList : []
      })
      let superiorId ='';
      if(msg.data.superiorId){
        let arr = this.state.modules.filter(v=>v.id === msg.data.superiorId);
        if(arr.length){
          superiorId = arr[0].name
        }
      }
      this.formRef.current.setFieldsValue({
           email:msg.data.email,
           position:msg.data.position,
           mobile:msg.data.mobile,
           status: msg.data.status,
           contactMobile:msg.data.contactMobile,
           name:msg.data.name,
           duty:msg.data.duty,
           headPortraitUrl:msg.data.headPortraitUrl? splitUrl(msg.data.headPortraitUrl, ',', this.props.test.initialState.globalConfig.avatarHost + '/upload') : '',
           departmentId:msg.data.departmentId,
           superiorId: superiorId,
           district:msg.data.district ? JSON.parse(msg.data.district) : null,
      });
    }else{
     message.error(msg.error.message);
    }
  }

  async componentDidMount() {
    if(!this.props.userId){
      this.getNewId();
    }else if(this.props.userId){
      this.setState({
        loading: true,
      });
      await this.handleSearchModule('');
      await this.getUserRole(this.props.userId);
      await this.getSelectAllByid(this.props.userId);
      this.setState({
        loading: false,
      });
    }
  }

  formRef = React.createRef();

  render() {
    const {userId} = this.props;
    return (
      <ModalForm
        formRef={this.formRef}
        visible={this.props.visible}
        preserve={false}
        title={userId ? '编辑用户': '新建用户'}
        modalProps={{
          onCancel: (e) => {e.stopPropagation();this.props.onCancel();this.setState({fileList:[]})},
        }}
        onFinish={userId ? this.updateAdmin : this.addUser}
      >
        <Spin spinning={this.state.loading} indicator={antIcon}>
          <ProForm.Group>
            <ProFormText
              width="m"
              rules={[
                {
                  required:true,
                  message:'请输入用户名'
                }
              ]}
              placeholder="请输入用户名"
              name="mobile"
              label="用户名"
            />
            <ProFormSelect
              mode="multiple"
              allowClear
              width="m"
              rules={[
                {
                  required:true,
                  message:'请选择用户角色'
                }
              ]}
              placeholder="请选择用户角色"
              label='用户角色'
              name="roles"
              request={this.getRolesList}/>
          </ProForm.Group>
          <ProForm.Group>
            <ProFormText
              width="m"
              rules={[
                {
                  required:true,
                  message:'请输入用户姓名'
                }
              ]}
              placeholder="请输入用户姓名"
              name="name"
              label="用户姓名"
            />
            <Form.Item
              rules={[
                {
                  required:true,
                  message:'请选择上级主管'
                }
              ]}
              label="上级主管"
              name='superiorId'
            >
              <AutoComplete
                style={{
                  width:'328px'
                }}
                onSearch={this.handleSearchModule}
                placeholder="请输入名称"
              >
                {this.state.modules.map((v) => (
                  <Option key={v.id} value={v.name}>
                    {v.name}
                  </Option>
                ))}
              </AutoComplete>
            </Form.Item>
            <ProForm.Group>
              <ProFormSelect
                width="m"
                rules={[
                  {
                    required:true,
                    message:'请选择组织部门'
                  }
                ]}
                placeholder="请选择组织部门"
                label='组织部门'
                name="departmentId"
                request={this.departmentList}/>
              <ProFormSelect
                width="m"
                placeholder="请选择职务"
                label='职务'
                name="duty"
                request={this.getPost}/>
            </ProForm.Group>
            <ProForm.Group>
              <ProFormSelect
                width="m"
                placeholder="请选择岗位"
                label='岗位'
                name="position"
                request={this.getStation}/>
              <ProFormText
                width="m"
                rules={[
                  {
                    pattern: /^[A-Za-z0-9\-_]+[A-Za-z0-9\.\-_]*[A-Za-z0-9\-_]+@[A-Za-z0-9]+[A-Za-z0-9\.\-_]*(\.[A-Za-z0-9\.\-_]+)*[A-Za-z0-9]+\.[A-Za-z0-9]+[A-Za-z0-9\.\-_]*[A-Za-z0-9]+$/,
                    message: '不合法的邮箱格式!',
                  },
                ]}
                placeholder="请输入电子邮箱"
                name="email"
                label="电子邮箱"
              />
            </ProForm.Group>
            <ProForm.Group>
              <ProFormText
                width="m"
                rules={[
                  {
                    pattern: /^1\d{10}$/,
                    message: '不合法的手机号格式!',
                  }
                ]}
                placeholder="请输入手机号"
                name="contactMobile"
                label="联系方式"
              />
            </ProForm.Group>
            <ProFormSelect
              mode="multiple"
              allowClear
              width="m"
              placeholder="请选择地区"
              label='地区'
              name="district"
              request={this.getCityArr}/>
          </ProForm.Group>
          <ProForm.Group>
            {userId && <ProFormSelect
              width="m"
              rules={[
                {
                  required:true,
                  message:'请选择用户状态'
                }
              ]}
              placeholder="请选择用户状态"
              label='用户状态'
              name="status"
              request={this.getStatus}/>}
          </ProForm.Group>
          <ProForm.Group>
            <Form.Item label='用户头像'  name="headPortraitUrl" extra="图片建议：要清晰。">
              <ImgOperation
                domId='uploadAdminImg'
                uploadConfig={{
                  action:'/api/admin/superviser/uploadAdminImg',
                  multiple:false,
                  data:{ 'sign': this.props.pictureSign || '' },
                  listType:"picture-card",
                  maxCount:1
                }}
                onChange={(infor)=>{
                  this.setState({
                    fileList: infor.fileList,
                  });
                }}
                fileList={this.state.fileList}
                onUploadState={(v)=>{
                  this.setState({
                    uploadImgLoading: v.state === 'uploading'
                  })
                }}
              />
            </Form.Item>
          </ProForm.Group>
        </Spin>
      </ModalForm>
    )
  }
}

export default AddUser;
