import React, {Component} from 'react';
import {Button, Form, message, Popconfirm} from "antd";
import DataTable from "@/components/common/DataTable";
import {ProFormSelect} from "@ant-design/pro-form";
import {getRolesList,getSelectSuperId} from '@/services/user';
import {post,station} from '@/utils/dataDic';
import {getPost,getStation} from '@/utils/tools.js';
import {updateAdmin,resetPwd} from './services/API';
import UnifiedTransfer from './compenents/unifiedTransfer';
import AddUser from './compenents/addUser';

class Administrators extends Component {
  constructor(props) {
    super(props);
    this.state = {
      columns: [{
        title: '用户编号',
        dataIndex: 'userNo',
        key: 'userNo',
      }, {
        title: '登录用户名',
        dataIndex: 'mobile',
        key: 'mobile',
        searchBool: true,
      }, {
        title: '角色',
        dataIndex: 'roles',
        key: 'rid',
        searchBool: true,
        renderFormItem: () => {
          return (
              <ProFormSelect label='' request={this.getRolesList}/>
          );
        },
      }, {
        title: '用户姓名',
        dataIndex: 'name',
        key: 'name',
        searchBool: true,
      }, {
        title: '部门',
        dataIndex: 'departmentName',
        key: 'departmentId',
        searchBool: true,
        renderFormItem: () => {
          return (
            <ProFormSelect label='' request={this.departmentList}/>
          );
        },
      }, {
        title: '职务',
        dataIndex: 'duty',
        key: 'duty',
        searchBool: true,
        render: text => {
          return getPost(text)
        },
        renderFormItem: () => {
          return (
              <ProFormSelect label='' request={this.getPost}/>
          );
        }
      }, {
        title: '岗位',
        dataIndex: 'position',
        key: 'position',
        searchBool: true,
        render: text => {
          return getStation(text)
        },
        renderFormItem: () => {
          return (
              <ProFormSelect label='' request={this.getStation}/>
          );
        }
      }, {
        title: '上级主管姓名',
        dataIndex: 'superior',
        key: 'superior',
        searchBool: true,
      }, {
        title: '状态',
        dataIndex: 'status',
        key: 'status',
        searchBool: true,
        valueType: 'select',
        valueEnum: {
          '正常': {
            text: '正常',
            status: 'Success',
          },
          '锁定': {
            text: '锁定',
            status: 'Warning',
          },
          '注销': {
            text: '注销',
            status: 'Error',
          },
        },
      }, {
        title: '最后登录时间',
        dataIndex: 'lastLoginTime',
        key: 'lastLoginTime',
      },{
        title: '操作',
        dataIndex: 'id',
        key: 'id',
        fixed: 'right',
        align: 'center',
        width: 315,
        render:(text,record,key,action)=>(
          <>
            {record.status === '正常' ? <Popconfirm
              title="是否锁定?"
              onConfirm={(e)=>{e.stopPropagation();this.locking(record,action)}}
              onCancel={(e)=>{e.stopPropagation();}}
              okText="确认"
              cancelText="取消"
              placement="topLeft">
              <Button type="primary" onClick={(e)=>e.stopPropagation()}>
                锁定
              </Button>
            </Popconfirm> : record.status === '锁定' ?
            <Popconfirm
              title="是否激活?"
              onConfirm={(e)=>{e.stopPropagation();this.activation(record,action)}}
              onCancel={(e)=>{e.stopPropagation();}}
              okText="确认"
              cancelText="取消"
              placement="topLeft">
              <Button type="primary" onClick={(e)=>e.stopPropagation()}>
                激活
              </Button>
            </Popconfirm> : null}
            <Popconfirm
              title="是否重置密码?"
              onConfirm={(e)=>{e.stopPropagation();this.resetUserPwd(text,action);}}
              onCancel={(e)=>{e.stopPropagation();}}
              okText="确认"
              cancelText="取消"
              placement="topLeft">
              <Button danger style={{marginLeft:'15px'}} onClick={(e)=>{e.stopPropagation();}}>
                重置密码
              </Button>
            </Popconfirm>
            <Button type='primary' style={{marginLeft:'15px'}} danger onClick={(e)=>{
              e.stopPropagation();
              this.setState({
                visible: true,
                userId: text,
              })
            }}>
              离职一键转交
            </Button>
          </>
        )
      }],
      visible: false,
      addUserVisible: false,
      userId: '',
    }
  }

  resetUserPwd= async (id,action) =>{
    message.loading({content:'重置中...',key:'resetPwd'})
    const msg = await resetPwd(id);
    if(msg.error.length === 0){
      message.success({content:'重置成功',key:'resetPwd',duration:2.5});
      action.reload();
    }else{
      message.error({content:msg.error[0].message,key:'resetPwd',duration:2.5})
    }
  }

  // 锁定
  locking=async (record,action)=>{
    message.loading({content:'锁定中...',key:'updateAdmin'})
    const msg = await updateAdmin({
      roles:record.rolesId,
      data:JSON.stringify({
        id: record.id,
        status: '锁定',
        name: record.name,
        mobile: record.mobile,
      }),
    });
    if(msg.error.length === 0){
      message.success({content:'锁定成功',key:'updateAdmin',duration:2.5});
      action.reload();
    }else{
      message.error({content:msg.error[0].message,key:'updateAdmin',duration:2.5})
    }
  }

  // 激活
  activation=async (record,action)=>{
    message.loading({content:'激活中...',key:'activation'})
    const msg = await updateAdmin({
      roles:record.rolesId,
      data:JSON.stringify({
        id: record.id,
        status: '正常',
        name: record.name,
        mobile: record.mobile,
      }),
    });
    if(msg.error.length === 0){
      message.success({content:'激活成功',key:'activation',duration:2.5});
      action.reload();
    }else{
      message.error({content:msg.error[0].message,key:'activation',duration:2.5})
    }
  }

  getRolesList= async ()=>{
    const msg = await getRolesList();
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.map((item, index)=> {
        theArr.push({
          label: item.roleName,
          value: item.id
        })
      })
    }else{
      message.error(msg.error[0].message)
    }
    return theArr;
  }

  departmentList = async() => {
    const msg = await getSelectSuperId();
    let theArr = [];
    if(msg.error.length === 0){
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
    }else{
      message.info(msg.error[0].message)
    }
    return theArr;
  }

  getPost = async () => {
    post.map((v)=>{
      v.label = v.key;
      return v;
    })
    return post;
  }

  getStation = async () => {
    station.map((v)=>{
      v.label = v.key;
      return v;
    })
    return station;
  }

  render() {
    const ref = React.createRef();
    return (
      <>
        <DataTable
          ref={ref}
          headerTitle='管理员列表'
          url='/api/admin/superviser/adminList'
          rowKey='id'
          scroll={{x:1500}}
          columns={this.state.columns}
          search={{
            filterType: 'query',
            labelWidth: 'auto',
            defaultCollapsed: false,
          }}
          onRow={(record) => ({
            onClick: (e) => {
              e.stopPropagation();
              this.setState({
                addUserVisible: true,
                userId: record.id
              })
            }
          })}
          toolBarRender={[
            <Button
              type='primary'
              key='addUser'
              onClick={(e)=>{
                e.stopPropagation();
                this.setState({
                  addUserVisible: true,
                  userId: ''
                })
              }}
            >
              新增用户
            </Button>
          ]}
        />
        {this.state.visible && <UnifiedTransfer
          userId={this.state.userId}
          visible={this.state.visible}
          onCancel={()=>{
            this.setState({
              visible:false,
              userId: '',
            })
          }}
        />}
        {this.state.addUserVisible && <AddUser
          userId={this.state.userId}
          tableRef={ref}
          visible={this.state.addUserVisible}
          onCancel={()=>{
            this.setState({
              addUserVisible: false,
              userId: ''
            })
          }}
        />}
      </>
    );
  }
}

export default Administrators;
