import React, { Component } from 'react';
import ProForm, {ModalForm, ProFormSelect, ProFormText,ProFormDigit} from "@ant-design/pro-form";
import {urlType} from "@/utils/dataDic";
import {selectAllById, selectName,updateById} from '../services/API';
import { LoadingOutlined } from '@ant-design/icons';
import {message,Form,AutoComplete,Spin} from "antd";

const { Option } = AutoComplete;

const antIcon = <LoadingOutlined style={{ fontSize: 24 }} spin />;

class AuthorityDetails extends Component{
  constructor(props) {
    super(props);
    this.state={
      detailsData: {},
      modules: [],
      spinning: false,
    }
    this.handleSearchModule = this.handleSearchModule.bind(this);
    this.updateDetailsData = this.updateDetailsData.bind(this);
  }

  // 查看基本详情基本信息
  loaduser= async (id)=>{
    this.setState({
      spinning: true
    })
    const msg = await selectAllById(id);
    if(msg.error.length === 0){
      msg.data.createTime = new Date(msg.data.createTime).toLocaleString();
      msg.data.updateTime = new Date(msg.data.updateTime).toLocaleString();
      this.setState({
        detailsData: msg.data,
        spinning: false
      });
      this.formRef.current.setFieldsValue({
        name:msg.data.name,
        url:msg.data.url,
        type:msg.data.type,
        showOrder:msg.data.showOrder,
        createId:msg.data.createId,
        superId:msg.data.superId,
      })
    }else{
      message.error(msg.error[0].message);
      this.setState({
        spinning: false
      });
    }
  }

  handleSearchModule=async (value)=>{
    const msg = await selectName(value);
    if(msg.error.length === 0){
      this.setState({
        modules: msg.data
      })
    }else{
      message.error(msg.error[0].message)
    }
  }

  updateDetailsData= async (value)=>{
    message.loading({content:'保存中...',key:'updateDetailsData'});
    value.id = this.state.detailsData.id;
    const msg = await updateById(value);
    if(msg.error.length === 0){
      message.success({content:'保存成功',key:'updateDetailsData', duration: 2});
      this.props.tableRef.current.reload();// 刷新列表
      this.props.onCancel();
    }else{
      message.error({content:msg.error[0].message,key:'updateDetailsData', duration: 2})
    }
  }

  componentDidMount() {
    this.props.detailsInfor && this.loaduser(this.props.detailsInfor.id);
  }

  formRef = React.createRef();

  render() {
    const {detailsData} = this.state;
    return (
      <ModalForm
        formRef={this.formRef}
        layout='horizontal'
        title="权限详情"
        visible={this.props.visible}
        initialValues={{

        }}
        modalProps={{
          onCancel: this.props.onCancel,
        }}
        onFinish={this.updateDetailsData}
      >
        <Spin indicator={antIcon} spinning={this.state.spinning}>
          <ProForm.Group>
            <ProFormText
              rules={
                [{
                  required: true,
                  message: '请输入接口名称!',
                }]
              }
              width="xl"
              name="name"
              label="接口名称："
              placeholder="请输入名称"
            />
          </ProForm.Group>
          <ProForm.Group>
            <ProFormText
              rules={
                [{
                  required: true,
                  message: '请输入接口路径'
                }]
              }
              width="xl"
              name="url"
              label="接口路径："
              placeholder="请输入接口路径"
            />
          </ProForm.Group>
          <ProForm.Group>
            <ProFormSelect
              rules={[
                {
                  required:true,
                  message:'请选择接口类型'
                }
              ]}
              width="xl"
              name="type"
              label="接口类型："
              placeholder="请选择接口类型"
              request={async () => urlType}
            />
          </ProForm.Group>
          <Form.Item
            label="上级功能模块:"
            name='superId'
          >
            <AutoComplete
              style={{
                width: 200,
              }}
              onSearch={this.handleSearchModule}
              placeholder="请选择上级功能模块"
            >
              {this.state.modules.map((email) => (
                <Option key={email.name} value={email.name}>
                  {email.name}
                </Option>
              ))}
            </AutoComplete>
          </Form.Item>
          <ProForm.Group>
            <ProFormDigit
              width="xl"
              name="showOrder"
              label="排序数字："
              placeholder="请输入排序数字"
            />
          </ProForm.Group>
          <Form.Item
            label="权限编号:"
          >
            <span>{detailsData.autNo}</span>
          </Form.Item>
          <Form.Item
            name='createId'
            label="创建人:"
          >
            <span>{detailsData.createId}</span>
          </Form.Item>
          <Form.Item
            label="创建时间:"
          >
            <span>{detailsData.createTime}</span>
          </Form.Item>
          <Form.Item
            label="更新时间:"
          >
            <span>{detailsData.updateTime}</span>
          </Form.Item>
        </Spin>
      </ModalForm>
    )
  }
}

export default AuthorityDetails;
