import React,{Component} from "react";
import ProForm, {
  ProFormSwitch,
  ProFormText,
  ProFormRadio,
  ProFormCheckbox,
  ProFormRate,
  ProFormDatePicker,
  ProFormSelect,
  ProFormDigit,
  ProFormDateTimePicker,
  ProFormSlider,
  ProFormDateTimeRangePicker,
  ProFormDateRangePicker,
  ProFormUploadButton,
  ProFormUploadDragger,
  ProFormFieldSet,
} from '@ant-design/pro-form';
import moment from "moment";
import {getSelectSuperId} from "@/services/user";
import {message} from "antd";
import {selectLvlList,updatePersonnel} from '../../services/API';

class Inauguration extends Component{
  constructor(props) {
    super(props);
    this.state={
      jobs: '',
    }
  }

  componentDidMount() {
    console.log(this.props.userInfor)
    this.formRef.current.setFieldsValue({
      status: this.props.userInfor.status,
      jobNature: this.props.userInfor.jobNature,
      system: this.props.userInfor.system,
      workingYear: this.props.userInfor.workingYear,
      entryTimes: this.props.userInfor.entryTimes,
      promotionTimes: this.props.userInfor.promotionTimes,
      lvl: this.props.userInfor.lvl,
      jobs: this.props.userInfor.jobs,
      allowance: this.props.userInfor.allowance,
      star: this.props.userInfor.star,
      company: this.props.userInfor.company,
    })
    this.setState({
      jobs: this.props.userInfor.jobs,
    })
  }

  // 部门
  departmentList = async() => {
    const msg = await getSelectSuperId();
    if(msg.error.length === 0){
      let theArr = [];
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
      return theArr;
    }else{
      message.warning(msg.error[0].message)
    }
    return [];
  }

  getSelectLvlList = async() => {
    const msg = await selectLvlList();
    if(msg.error.length === 0){
      let theArr = [];
      msg.data.filter(v=>v.jobs === this.state.jobs).forEach((item) => {
        theArr.push({
          label: item.lvlName,
          value: item.lvl
        });
      });
      return theArr;
    }else{
      message.warning(msg.error[0].message)
    }
    return [];
  }

  updatePersonnel= async (value)=>{
    console.log(value);
    try{
      value.id = this.props.userInfor.id;
      const msg = await updatePersonnel(value);
      if(msg.error.length === 0){
        message.success({content:'保存成功',key:'updatePersonnel',duration:2.5});
      }else{
        message.warning({content:msg.error[0].message,key:'updatePersonnel',duration:2.5})
      }
    }catch (error){
      console.log(error)
      return true;
    }
  }

  formRef = React.createRef();

  render() {
    return (
      <>
        <div
          style={{
            fontSize: '20px',
            backgroundColor: 'skyblue',
            textAlign: "center",
            marginBottom: 10,
            letterSpacing: '7px',
            fontWeight: 'bold',
            lineHeight:'20px',
            paddingBottom: '14px',
            paddingTop: '10px',
          }}
        >
          任职信息
        </div>
        <ProForm
          formRef={this.formRef}
          onFinish={this.updatePersonnel}
          submitter={!this.props.readonly}
          layout={this.props.readonly?'horizontal':'vertical'}
          onValuesChange={(v)=>{
            if(v.hasOwnProperty('jobs')){
              this.setState({
                jobs: ''
              },()=>{
                this.setState({
                  jobs: v.jobs
                })
              })
            }
          }}
        >
          <ProForm.Group>
            <ProFormSelect
              readonly={this.props.readonly}
              width="xs"
              name="status"
              label="员工状态"
              placeholder="请选择员工状态"
              options={[
                {
                  value: 0,
                  label: '实习生',
                },
                {
                  value: 1,
                  label: '在职（试用期）',
                },
                {
                  value: 2,
                  label: '在职（合同期）',
                },
                {
                  value: 3,
                  label: '兼职',
                },
                {
                  value: 4,
                  label: '已离职',
                },
              ]}
            />
            <ProFormSelect
              readonly={this.props.readonly}
              width="xs"
              name="system"
              label="所属系统"
              placeholder="请选择所属系统"
              options={[
                {
                  value: 0,
                  label: '管理系统',
                },
                {
                  value: 1,
                  label: '营销系统',
                },
                {
                  value: 2,
                  label: '技术系统',
                },
              ]}
            />
            <ProFormSelect
              readonly={this.props.readonly}
              width="xs"
              name="jobNature"
              label="工作性质"
              placeholder="请选择工作性质"
              options={[
                {
                  value: '0',
                  label: '全职',
                },
                {
                  value: '1',
                  label: '兼职',
                },
                {
                  value: '2',
                  label: '其他',
                },
              ]}
            />
            <ProFormDatePicker
              readonly={this.props.readonly}
              width="xs"
              label="入职时间"
              name="entryTimes"
              placeholder="请选择入职时间"
            />
            <ProFormDatePicker
              readonly={this.props.readonly}
              width="xs"
              label="转正时间"
              name="promotionTimes"
              placeholder="请选择转正时间"
            />
          </ProForm.Group>
          <ProForm.Group>
            <ProFormSelect
              readonly={this.props.readonly}
              width="xs"
              label='所属公司'
              name='company'
              placeholder="请选择所属公司"
              request={this.departmentList}/>
            <ProFormSelect
              readonly={this.props.readonly}
              width="xs"
              name="lvl"
              label="级别"
              placeholder="请选择级别"
              options={[
                {
                  value: 0,
                  label: '员工',
                },
                {
                  value: 1,
                  label: '主管',
                },
                {
                  value: 2,
                  label: '经理',
                },
                {
                  value: 3,
                  label: '总经理',
                },
                {
                  value: 4,
                  label: '副总裁',
                },
                {
                  value: 5,
                  label: '副总',
                },
                {
                  value: 6,
                  label: '总监',
                },
                {
                  value: 7,
                  label: '董事长',
                },
              ]}
            />
            <ProFormSelect
              readonly={this.props.readonly}
              width="xs"
              name="jobs"
              label="职位"
              placeholder="请选择职位"
              options={[
                {
                  value: 1,
                  label: '员工',
                },
                {
                  value: 2,
                  label: '试用营销员',
                },
                {
                  value: 3,
                  label: '试用营销储备经理',
                },
                {
                  value: 4,
                  label: '营销经理',
                },
                {
                  value: 5,
                  label: '总监合伙人',
                },
                {
                  value: 6,
                  label: '技术助理',
                },
                {
                  value: 7,
                  label: '咨询师',
                },
                {
                  value: 8,
                  label: '咨询师主管',
                },
                {
                  value: 9,
                  label: '咨询师经理',
                },
                {
                  value: 10,
                  label: '高级经理',
                },
              ]}
            />
            {this.state.jobs ? <ProFormSelect
              readonly={this.props.readonly}
              width="xs"
              label='星级'
              name='star'
              placeholder="请选择星级"
              request={this.getSelectLvlList}/> : null}
            <ProFormDigit
              readonly={this.props.readonly}
              width="xs"
              placeholder="请输入岗位津贴"
              name="allowance"
              label="岗位津贴"/>
            <ProFormDigit
              readonly
              width="xs"
              placeholder="请输入工龄"
              name="workingYear"
              label="工龄"/>
          </ProForm.Group>
        </ProForm>
      </>
    )
  }
}

export default Inauguration;
