import React,{Component} from 'react';
import ProForm, {
  ModalForm,
  ProFormText,
  ProFormDatePicker,
  ProFormRadio,
  ProFormDigit, ProFormSelect
} from "@ant-design/pro-form";
import {Input, Cascader, Form, message} from "antd";
import {getAddressSelect,getNativePlace} from "@/utils/tools";
import {addEmployees,checkEmployeeId,checkDoorId,updateEmployees} from '../services/API';

const { Search } = Input;

class NewEmployees extends Component{
  constructor(props) {
    super(props);
    this.state={
      addressSelect:[],
      nativePlaceSelect:[],
      verifyIdLoading: false,
      doorIdLoading: false
    }
    this.verifyId = this.verifyId.bind(this);
    this.verifyDoor = this.verifyDoor.bind(this);
    this.updateEmployees = this.updateEmployees.bind(this);
  }

  addEmployees= async (value)=>{
    message.loading({content:'保存中...',key:'addEmployees'});
    // 户籍地址
    value.residenceProvince = value.address ? value.address[0] || undefined : undefined;
    value.residenceCity = value.address ? value.address[1] || undefined : undefined;
    value.residenceArea = value.address ? value.address[2] || undefined : undefined;
    // 现住地址
    value.nowProvince = value.userNowAddress ? value.userNowAddress[0] || undefined : undefined;
    value.nowCity = value.userNowAddress ? value.userNowAddress[1] || undefined : undefined;
    value.nowArea = value.userNowAddress ? value.userNowAddress[2] || undefined : undefined;
    // 籍贯
    value.nativePlaceProvince = value.nativePlace ? value.nativePlace[0] || undefined : undefined;
    value.nativePlaceCity = value.nativePlace ? value.nativePlace[1] || undefined : undefined;
    // 性别
    value.sex = value.sex === '男' ? 0 : value.sex === '女' ? 1 : undefined;
    // 婚否
    value.marriage = value.marriage === '未婚' ? 0 : value.marriage === '已婚' ? 1 : value.marriage === '离异' ? 2 : undefined
    try {
      const msg = await addEmployees(value);
      if(msg.error.length === 0){
        message.success({content:'保存成功',key:'addEmployees',duration:2.5});
        this.props.formRef.current.reload();
        this.props.onCancel();
      }else{
        message.error({content:msg.error[0].message,key:'addEmployees',duration:2.5})
      }
    } catch (e){
      console.log(e)
      return false;
    }
  }

  updateEmployees=async (value)=>{
    message.loading({content:'修改中...',key:'updateEmployees'});
    // 户籍地址
    value.residenceProvince = value.address ? value.address[0] || undefined : undefined;
    value.residenceCity = value.address ? value.address[1] || undefined : undefined;
    value.residenceArea = value.address ? value.address[2] || undefined : undefined;
    // 现住地址
    value.nowProvince = value.userNowAddress ? value.userNowAddress[0] || undefined : undefined;
    value.nowCity = value.userNowAddress ? value.userNowAddress[1] || undefined : undefined;
    value.nowArea = value.userNowAddress ? value.userNowAddress[2] || undefined : undefined;
    // 籍贯
    value.nativePlaceProvince = value.nativePlace ? value.nativePlace[0] || undefined : undefined;
    value.nativePlaceCity = value.nativePlace ? value.nativePlace[1] || undefined : undefined;
    // 性别
    value.sex = value.sex === '男' ? 0 : value.sex === '女' ? 1 : undefined;
    // 婚否
    value.marriage = value.marriage === '未婚' ? 0 : value.marriage === '已婚' ? 1 : value.marriage === '离异' ? 2 : undefined;

    value.id = this.props.userInfor.id;

    delete value.address;
    delete value.userNowAddress;
    delete value.nativePlace;
    try {
      const msg = await updateEmployees(value);
      if(msg.error.length === 0){
        message.success({content:'修改成功',key:'updateEmployees',duration:2.5});
        this.props.formRef.current.reload();
        this.props.onCancel();
        this.props.onUpdate();
      }else{
        message.error({content:msg.error[0].message,key:'updateEmployees',duration:2.5})
      }
    } catch (e){
      console.log(e)
      return false;
    }
  }

  setAddressList = async () => {
    let addressSelect = await getAddressSelect();
    addressSelect.unshift({
      label: '全国',
      value: 0,
    })
    let nativePlaceSelect = await getNativePlace();
    this.setState({
      addressSelect,
      nativePlaceSelect
    })
  }

  verifyId = async () => {
    let employeeId = this.formRef.current.getFieldsValue(['employeeId']).employeeId;
    if(!employeeId){
      message.warning('员工编号不能为空');
      return;
    }
    message.loading({content:'检验中...',key:'verifyId'});
    this.setState({
      verifyIdLoading:true,
    })
    try {
      const msg = await checkEmployeeId(employeeId,this.props.userInfor ? this.props.userInfor.id : undefined);
      if(msg.error.length === 0){
        message.success({content:'此编号未被占用',key:'verifyId',duration:2.5});
      }else{
        message.error({content:msg.error[0].message,key:'verifyId',duration:2.5})
      }
    }catch (error){
      console.log(error)
    }
    this.setState({
      verifyIdLoading:false,
    })
  }

  verifyDoor = async () => {
    let doorId = this.formRef.current.getFieldsValue(['doorId']).doorId;
    if(!doorId){
      message.warning('门禁编号不能为空');
      return;
    }
    message.loading({content:'检验中...',key:'verifyDoor'});
    this.setState({
      doorIdLoading:true,
    })
    try {
      const msg = await checkDoorId(doorId,this.props.userInfor ? this.props.userInfor.id : undefined);
      if(msg.error.length === 0){
        message.success({content:'此编号未被占用',key:'verifyDoor',duration:2.5});
      }else{
        message.error({content:msg.error[0].message,key:'verifyDoor',duration:2.5})
      }
    }catch (error){
      console.log(error)
    }
    this.setState({
      doorIdLoading:false,
    })
  }

  componentDidMount() {
    this.setAddressList();
    if(this.props.userInfor){
      let data = this.props.userInfor;
      this.formRef.current.setFieldsValue({
        employeeId: data.employeeId,
        doorId: data.doorId,
        name: data.name,
        birthdays: data.birthdays,
        idCard: data.idCard,
        sex: data.sex === 0 ? '男' : '女',
        address: [data.residenceProvince,data.residenceCity,data.residenceArea],
        nativePlace: [data.nativePlaceProvince,data.nativePlaceCity],
        residenceAddress: data.residenceAddress,
        userNowAddress: [data.nowProvince,data.nowCity,data.nowArea],
        nowAddress: data.nowAddress,
        nation: data.nation,
        certificationAuthority: data.certificationAuthority,
        marriage: data.marriage === 0 ? '未婚' : data.marriage === 1 ? '已婚' : data.marriage === 2 ? '离异' : undefined,
        son: data.son,
        girl: data.girl,
        politicalOutlook: data.politicalOutlook
      })
    }
  }

  formRef = React.createRef();

  render() {
    return (
      <ModalForm
        formRef={this.formRef}
        visible={this.props.visible}
        preserve={false}
        title={this.props.userInfor ? '修改人事档案' : '新增人事档案'}
        modalProps={{
          destroyOnClose:true,
          onCancel: (e) => {e.stopPropagation();this.props.onCancel();},
        }}
        onFinish={this.props.userInfor ? this.updateEmployees : this.addEmployees}
      >
        <ProForm.Group>
          <Form.Item
            name="employeeId"
            width="m"
            rules={[
              {
                required:true,
                message:'请输入员工编号'
              },
              {
                pattern: /^[^\u4e00-\u9fa5]+$/,
                message: '员工编号不能包含中文',
              }
            ]}
            label="员工编号">
            <Search
              loading={this.state.verifyIdLoading}
              style={{width:328}}
              placeholder="请输入员工编号"
              onSearch={this.verifyId}
              enterButton="验证重复"/>
          </Form.Item>
          <Form.Item
            name="doorId"
            width="m"
            rules={[
              {
                required:true,
                message:'请输入门禁编号'
              },
              {
                pattern: /^[^\u4e00-\u9fa5]+$/,
                message: '门禁编号不能包含中文',
              }
            ]}
            label="门禁编号">
            <Search
              loading={this.state.doorIdLoading}
              style={{width:328}}
              placeholder="请输入门禁编号"
              onSearch={this.verifyDoor}
              enterButton="验证重复"/>
          </Form.Item>
        </ProForm.Group>
        <ProForm.Group>
          <ProFormText
            width="m"
            rules={[
              {
                required:true,
                message:'请输入姓名'
              }
            ]}
            placeholder="请输入姓名"
            name="name"
            label="姓名"/>
          <ProFormDatePicker
            width="m"
            rules={[
              {
                required:true,
                message:'请选择出生日期'
              }
            ]}
            name="birthdays"
            label="出生日期"
            placeholder="请选择出生日期"
          />
        </ProForm.Group>
        <ProForm.Group>
          <ProFormText
            width="m"
            rules={[
              {
                required:true,
                message:'请输入身份证'
              },
              {
                pattern: /^[1-9]\d{7}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])\d{3}$|^[1-9]\d{5}[1-9]\d{3}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])\d{3}([0-9]|X)$/,
                message: '不合法的身份证格式',
              }
            ]}
            placeholder="请输入身份证"
            name="idCard"
            label="身份证"/>
          <ProFormRadio.Group
            label="性别"
            width="m"
            name="sex"
            options={['男','女']}
          />
        </ProForm.Group>
        <ProForm.Group>
          <Form.Item
            label="户籍地址:"
            name='address'
          >
            <Cascader
              changeOnSelect
              style={{
                width: '329px',
              }}
              options={this.state.addressSelect}
              placeholder='请选择户籍地址'/>
          </Form.Item>
          <ProFormText
            width="m"
            placeholder="请输入户籍街道地址"
            name="residenceAddress"
            label="户籍街道地址"/>
        </ProForm.Group>
        <ProForm.Group>
          <Form.Item
            label="现住地址:"
            name='userNowAddress'
          >
            <Cascader
              changeOnSelect
              style={{
                width: '329px',
              }}
              options={this.state.addressSelect}
              placeholder='请选择现住地址'/>
          </Form.Item>
          <ProFormText
            width="m"
            placeholder="请输入现住街道地址"
            name="nowAddress"
            label="现住街道地址"/>
        </ProForm.Group>
        <ProForm.Group>
          <Form.Item
            label="籍贯:"
            name='nativePlace'
          >
            <Cascader
              changeOnSelect
              style={{
                width: '329px',
              }}
              options={this.state.nativePlaceSelect}
              placeholder='请选择籍贯'/>
          </Form.Item>
          <ProFormText
            width="m"
            placeholder="请输入民族"
            name="nation"
            label="民族"/>
        </ProForm.Group>
        <ProForm.Group>
          <ProFormText
            width="m"
            placeholder="请输入身份证领证机关"
            name="certificationAuthority"
            label="身份证领证机关"/>
          <ProFormRadio.Group
            label="婚姻状态"
            name="marriage"
            options={['未婚','已婚','离异']}
          />
        </ProForm.Group>
        <ProForm.Group>
          <ProFormDigit
            width="m"
            placeholder="请输入儿子数量"
            name="son"
            label="儿子数量"/>
          <ProFormDigit
            width="m"
            placeholder="请输入女儿数量"
            name="girl"
            label="女儿数量"/>
        </ProForm.Group>
        <ProForm.Group>
          <ProFormSelect
            width="m"
            name="politicalOutlook"
            label="政治面貌"
            placeholder="请选择政治面貌"
            options={[
              {
                value: 0,
                label: '群众',
              },
              {
                value: 1,
                label: '中共预备党员',
              },
              {
                value: 2,
                label: '中共党员',
              },
              {
                value: 3,
                label: '致公党员',
              },
            ]}
          />
        </ProForm.Group>
      </ModalForm>
    )
  }
}

export default NewEmployees;
