import React,{Component} from 'react';
import Modal from '@/components/common/Modal';
import {Button, Descriptions, message, Spin, Tooltip} from 'antd';
import {getSelectBypdId} from '../services/API';
import DataClassify from './dataClassify/index';
import NewEmployees from "@/pages/personnel/archives/statistics/components/newEmployees";

class PersonnelDetails extends Component{
  constructor(props) {
    super(props);
    this.state={
      doorDetails:{},
      loading: false,
      table: [
        {
          key: "员工编号",
          value: "employeeId",
        },
        {
          key: "姓名",
          value: "name",
        },
        {
          key: "出生日期",
          value: "birthdays",
        },
        {
          key: "出生月份",
          value: "month",
        },
        {
          key: "门禁编号",
          value: "doorId",
        },
        {
          key: "性别",
          value: "sex",
        },
        {
          key: "年龄",
          value: "age",
        },
        {
          key: "民族",
          value: "nation",
        },
        {
          key: "户籍地址",
          value: "residenceName",
        },
        {
          key: "籍贯",
          value: "nativePlaceName",
        },
        {
          key: "身份证",
          value: "idCard",
        },
        {
          key: "领证机关",
          value: "certificationAuthority",
        },
        {
          key: "现住地址",
          value: "nowName",
        },
        {
          key: "婚姻状态",
          value: "marriageName",
        },
        {
          key: "子/女",
          value: "son",
        },
        {
          key: "政治面貌",
          value: "politicalOutlookName",
        },
      ],
      visible: false,
      employeesVisible: false,
      readonly: false,
    }
    this.getCheckDoorDetails = this.getCheckDoorDetails.bind(this);
  }

  getCheckDoorDetails= async ()=>{
    this.setState({
      loading: true
    })
    const {userInfo} = this.props;
    const msg = await getSelectBypdId(userInfo.id);
    if(msg.error.length === 0){
      this.setState({
        doorDetails: msg.data
      })
    }else{
      message.warning(msg.error[0].message)
    }
    this.setState({
      loading: false
    })
  }

  componentDidMount() {
    this.getCheckDoorDetails();
  }

  render() {
    const {userInfo} = this.props;
    return (
      <>
        <Modal
          width={1240}
          title={userInfo.name+'人事档案'}
          footer={null}
          visible={this.props.visible}
          onCancel={(e) => {this.props.onCancel();}}
        >
          <Spin spinning={this.state.loading}>
            <Button type="primary" style={{marginBottom:'20px'}} onClick={()=>{this.setState({readonly:!this.state.readonly})}}>{this.state.readonly ? '切换查看模式' : '切换编辑模式'}</Button>
            <div style={{ cursor: 'pointer',paddingBottom:'20px'}} onClick={()=>{
              this.setState({
                employeesVisible: true,
              })
            }}>
              <Descriptions
                bordered
                column={{ xxl: 4, xl: 4, lg: 4, md: 4, sm: 2, xs: 1 }}>
                {
                  this.state.table.map((value,key)=>(
                    <Descriptions.Item label={value.key} key={key}>
                        <Tooltip
                          placement="top"
                          title={
                            value.value === 'sex' ? (this.state.doorDetails[value.value] === 0 ? '男' : '女') :
                              value.value === 'son' ? this.state.doorDetails[value.value] + '/' + this.state.doorDetails['girl'] :
                                this.state.doorDetails[value.value]
                          }
                        >
                          {
                            value.value === 'sex' ? (this.state.doorDetails[value.value] === 0 ? '男' : '女') :
                              value.value === 'son' ? this.state.doorDetails[value.value] + '/' + this.state.doorDetails['girl'] :
                                this.state.doorDetails[value.value] && this.state.doorDetails[value.value].length > 10 ?  this.state.doorDetails[value.value].slice(0,10)+'...':this.state.doorDetails[value.value]
                          }
                        </Tooltip>
                    </Descriptions.Item>
                  ))
                }
              </Descriptions>
            </div>
            {Object.keys(this.state.doorDetails).length > 0 ? <DataClassify
              readonly={this.state.readonly}
              userInfor={this.state.doorDetails}
            /> : null}

          </Spin>
        </Modal>
        {this.state.employeesVisible && <NewEmployees
          userInfor={this.state.doorDetails}
          formRef={this.props.formRef}
          visible={this.state.employeesVisible}
          onUpdate={this.getCheckDoorDetails}
          onCancel={()=>{
            this.setState({
              employeesVisible: false,
            })
          }}
        /> }
      </>
    )
  }
}

export default PersonnelDetails;
