import React,{Component} from "react";
import {Button, message} from "antd";
import DataTable from "@/components/common/DataTable";
import moment from 'moment';
import NewEmployees from './components/newEmployees';
import PersonnelDetails from './components/personnelDetails';
import {getSelectSuperId} from "@/services/user";
import {ProFormSelect} from "@ant-design/pro-form";

class Archives extends Component{
  constructor(props) {
    super(props);
    this.state={
      columns:[
        {
          title: "员工编号",
          dataIndex: "employeeId",
          key: "employeeId",
        },
        {
          title: "门禁编号",
          dataIndex: "doorId",
          key: "doorId",
        },
        {
          title: "名称",
          dataIndex: "name",
          key: "name",
          searchBool:true,
        },
        {
          title: "员工状态",
          dataIndex: "statusName",
          key: "status",
          searchBool:true,
          valueType: 'select',
          valueEnum: {
            '0': {
              text: '实习生',
            },
            '1': {
              text: '在职（试用期）',
            },
            '2': {
              text: '在职（合同期）',
            },
            '3': {
              text: '兼职',
            },
            '4': {
              text: '离职',
            },
          }
        },
        {
          title: "所属系统",
          dataIndex: "systemName",
          key: "system",
          searchBool: true,
          valueType: 'select',
          valueEnum: {
            '0': {
              text: '管理系统',
            },
            '1': {
              text: '营销系统',
            },
            '2': {
              text: '技术系统',
            },
          }
        },
        {
          title: "公司名称",
          dataIndex: "depName",
          key: "depName",
        },
        {
          title: "职位名称",
          dataIndex: "jobsName",
          key: "jobsName",
        },
        {
          title: "等级名称",
          dataIndex: "starName",
          key: "starName",
        },
        {
          title: "级别",
          dataIndex: "lvlName",
          key: "lvlName",
        },
        {
          title: "入职时间",
          dataIndex: "entryTimes",
          key: "entryTimes",
          valueType: 'dateRange',
          searchBool: true,
        },
        {
          title: "转正时间",
          dataIndex: "promotionTimes",
          key: "promotionTimes",
          valueType: 'dateRange',
          searchBool: true,
          render: (text) => {
            let time = moment(text).valueOf();
            let today = Date.parse(new Date());
            let sevenDay = 604800000;
            if (time - today < sevenDay) {
              return (
                <span style={{ color: "red", fontWeight: 900 }}>{text}</span>
              );
            }
            return text;
          },
        },
        {
          title: "生日日期",
          dataIndex: "birthdays",
          key: "birthdays",
        },
        {
          title: "性别",
          dataIndex: "sex",
          key: "sex",
          searchBool: true,
          valueType: 'select',
          valueEnum: {
            0:{
              text:'男'
            },
            1:{
              text:'女'
            }
          },
          render: (text) => {
            if (text === 0) {
              return "男";
            } else if (text === 1) {
              return "女";
            }
          },
        },
        {
          title: "婚姻状态",
          dataIndex: "marriageName",
          key: "marriage",
          searchBool: true,
          valueType: 'select',
          valueEnum: {
            "0":{
              text:'未婚'
            },
            "1":{
              text:'已婚'
            },
            "2":{
              text:'离异'
            }
          },
        },
        {
          title: "子/女",
          dataIndex: "son",
          key: "son",
          render: (text, record) => {
            return <span>{text + "/" + record.girl}</span>;
          },
        },
        {
          title: "政治面貌",
          dataIndex: "politicalOutlookName",
          key: "politicalOutlook",
          searchBool: true,
          valueType: 'select',
          valueEnum: {
            "0":{
              text:'群众'
            },
            "1":{
              text:'中共预备党员'
            },
            "2":{
              text:'中共党员'
            },
            "3":{
              text:'致公党员'
            }
          },
        },
        {
          title: "教育经历",
          dataIndex: "educationName",
          key: "education",
          searchBool: true,
          valueType: 'select',
          valueEnum: {
            "0": {
              text: '高中/中专'
            },
            "1": {
              text: '专科/高职'
            },
            "2": {
              text: '本科'
            },
            "3": {
              text: '研究生'
            },
            "5": {
              text: '博士'
            },
          }
        },
        {
          title: "毕业学校",
          dataIndex: "school",
          key: "school",
        },
        {
          title: "专业",
          dataIndex: "major",
          key: "major",
        },
        {
          title: "职称",
          dataIndex: "title",
          key: "title",
        },
        {
          title: "晋升备注",
          dataIndex: "promotionRemarks",
          key: "promotionRemarks",
        },
        {
          title: "晋升时间",
          dataIndex: "promotionTime",
          key: "promotionTime",
        },
        {
          title: "合同时间",
          dataIndex: "contractStart",
          key: "contractStart",
          valueType: 'dateRange',
          searchBool: true,
          render: (text, record) => {
            let end = moment(record.contractEnd).valueOf();
            let today = Date.parse(new Date());
            let sevenDay = 604800000;
            if (record.contractStart) {
              if (end - today < sevenDay) {
                return (
                  <span style={{ color: "red", fontWeight: 900 }}>
                    {record.contractStart + "~" + record.contractEnd}
                  </span>
                );
              }
              return record.contractStart + "~" + record.contractEnd;
            }
          },
        },
        {
          title: "手机号码",
          dataIndex: "mobile",
          key: "mobile",
        },
        {
          title: "电话",
          dataIndex: "fixedTel",
          key: "fixedTel",
        },
        {
          title: "身份证",
          dataIndex: "idCard",
          key: "idCard",
        },
        {
          title: "发证机构",
          dataIndex: "certificationAuthority",
          key: "certificationAuthority",
        },
        {
          title: "户籍地址",
          dataIndex: "residenceName",
          key: "residenceName",
        },
        {
          title: "籍贯",
          dataIndex: "nativePlaceName",
          key: "nativePlaceName",
        },
        {
          title: "现住地址",
          dataIndex: "nowName",
          key: "nowName",
        },
        {
          title: "紧急联系人",
          dataIndex: "emergencyContact",
          key: "emergencyContact",
        },
        {
          title: "紧急联系人电话",
          dataIndex: "emergencyMobile",
          key: "emergencyMobile",
        },
        {
          title: "离职时间",
          dataIndex: "quitTime",
          key: "quitTime",
          valueType: 'dateRange',
          searchBool: true,
        },
        {
          title: "工作年限",
          dataIndex: "workingYear",
          key: "workingYears",
          searchBool: true,
          valueEnum: {
            "0":{
              text:'0-1年'
            },
            "1":{
              text:'1-3年'
            },
            "2":{
              text:'3-10年'
            },
            "3":{
              text:'10年以上'
            }
          },
        },
        {
          title: "年龄",
          dataIndex: "age",
          key: "age",
        },
        {
          title: "出生月份",
          dataIndex: "month",
          key: "month",
        },
        {
          title: "参保时间",
          dataIndex: "insuranceStartTimes",
          key: "insuranceStartTimes",
        },
        {
          title: "停保时间",
          dataIndex: "insuranceEndTimes",
          key: "insuranceEndTimes",
        },
        {
          title: "公积金时间",
          dataIndex: "fundStartTimes",
          key: "fundStartTimes",
        },
        {
          title: "停办公积金时间",
          dataIndex: "fundEndTimes",
          key: "fundEndTimes",
        },
        {
          title: "所属公司",
          dataIndex: "company",
          key: "company",
          hideInTable: true,
          searchBool: true,
          renderFormItem: () => {
            return (
              <ProFormSelect label='' request={this.departmentList}/>
            );
          },
        },
        {
          title: "生日月份",
          dataIndex: "birthdayMonth",
          key: "birthdayMonth",
          hideInTable: true,
          searchBool: true,
          valueType: 'select',
          valueEnum: {
            "1":{
              text:'一月'
            },
            "2":{
              text:'二月'
            },
            "3":{
              text:'三月'
            },
            "4":{
              text:'四月'
            },
            "5":{
              text:'五月'
            },
            "6":{
              text:'六月'
            },
            "7":{
              text:'七月'
            },
            "8":{
              text:'八月'
            },
            "9":{
              text:'九月'
            },
            "10":{
              text:'十月'
            },
            "11":{
              text:'十一月'
            },
            "12":{
              text:'十二月'
            }
          },
        },
      ],
      visible:false,
      userInfo: {},
      personnelVisible: false,
    }
  }

  // 部门
  departmentList = async() => {
    const msg = await getSelectSuperId();
    if(msg.error.length === 0){
      let theArr = [];
      msg.data.forEach((item) => {
        theArr.push({
          label: item.name,
          value: item.id
        });
      });
      return theArr;
    }else{
      message.warning(msg.error[0].message)
    }
    return [];
  }

  render() {
    const ref = React.createRef();
    return (
      <>
        <DataTable
          ref={ref}
          headerTitle='人事档案统计'
          url='/api/admin/personnel/selectList'
          method='get'
          rowKey='id'
          scroll={{x:3500}}
          columns={this.state.columns}
          requestProcess={(v)=>{
            if(v && v.promotionTimes){
              v.promotionStart = v.promotionTimes[0];
              v.promotionEnd = v.promotionTimes[1];
              delete v.promotionTimes;
            }
            if(v && v.entryTimes){
              v.entryStart = v.entryTimes[0];
              v.entryEnd = v.entryTimes[1];
              delete v.entryTimes;
            }
            if(v && v.quitTime){
              v.quitStart = v.quitTime[0];
              v.quitEnd = v.quitTime[1];
              delete v.quitTime;
            }
            if(v && v.contractStart){
              v.contractEnd = v.contractStart[1];
              v.contractStart = v.contractStart[0];
            }
            return v;
          }}
          search={{
            filterType: 'query',
            labelWidth: 'auto',
            defaultCollapsed: false,
          }}
          onRow={(record) => ({
            onClick: (e) => {
              e.stopPropagation();
              this.setState({
                personnelVisible: true,
                userInfo: record,
              })
            }
          })}
          toolBarRender={[
            <Button
              type='primary'
              key='addUser'
              onClick={(e)=>{
                e.stopPropagation();
                this.setState({
                  visible: true,
                })
              }}
            >
              新增员工档案
            </Button>
          ]}
        />
        {this.state.visible && <NewEmployees
          formRef={ref}
          visible={this.state.visible}
          onCancel={()=>{
            this.setState({
              visible: false,
            })
          }}
        /> }
        {this.state.personnelVisible ? <PersonnelDetails
          formRef={ref}
          visible={this.state.personnelVisible}
          onCancel={()=>{
            this.setState({
              personnelVisible: false,
            })
          }}
          userInfo={this.state.userInfo}/> : null}
      </>
    )
  }
}

export default Archives;
